import json
from celery import Celery
from datetime import datetime
from srht.config import cfg
from srht.database import db
from srht.graphql import exec_gql
from srht.oauth import UserType
from srht.metrics import RedisQueueCollector
from prometheus_client import Counter

allow_free = cfg("builds.sr.ht", "allow-free", default="no") == "yes"

builds_broker = cfg("builds.sr.ht", "redis")
runner = Celery('builds', broker=builds_broker, config_source={
    "CELERY_TASK_SERIALIZER": "json",
    "CELERY_ACCEPT_CONTENT": ["json"],
    "CELERY_RESULT_SERIALIZER": "json",
    "CELERY_ENABLE_UTC": True,
    "CELERY_TASK_PROTOCOL": 1
})

builds_queue_metrics_collector = RedisQueueCollector(builds_broker, "buildsrht_builds", "Number of builds currently in queue")
builds_submitted = Counter("buildsrht_builds_submitted", "Number of builds submitted")

def submit_build(user, manifest, note=None, tags=[], visibility=None, valid=None):
    resp = exec_gql("builds.sr.ht", """
        mutation SubmitBuild($manifest: String!, $tags: [String!], $note: String, $visibility: Visibility) {
            submit(manifest: $manifest, tags: $tags, note: $note, visibility: $visibility) {
                id
            }
        }
    """, user=user, manifest=manifest, note=note, tags=tags, visibility=visibility, valid=valid)
    if valid and not valid.ok:
        return None
    return resp["submit"]["id"]

def requires_payment(user):
    if allow_free:
        return False

    resp = exec_gql("meta.sr.ht", """
        query {
            me {
                userType
            }
        }
    """, user=user)
    return resp["me"]["userType"] not in [
        "ADMIN",
        "ACTIVE_PAYING",
        "ACTIVE_FREE",
    ]

@runner.task
def run_build(job_id, manifest):
    pass # see worker/context.go
